function s = bruecke(uu1,rr2,rr3,rr4,rr5,rr6)
% s = bruecke(uu1,rr2,rr3,rr4,rr5,rr62)
% Brcke mit 5 Widerstnden
% uu1         :  Spannung der Spannungsquelle
% rr2 ... rr6 :  Widerstandswerte
% Ausgegeben werden die Spannungen und Strme der 
% 5 Komponenten als Resultatstring;

% Defaultwerte
% ============
if nargin<6 rr6 =  200; end
if nargin<5 rr5 = 1000; end
if nargin<4 rr4 =  200; end
if nargin<3 rr3 = 1000; end
if nargin<2 rr2 =  200; end
if nargin<1 uu1 =    5; end

syms u1 r2 r3 r4 r5 r6                   % symbolische Variable

% Koeffizientenmatrix a und rechte Seite b des linearen Gleichungssystems
% =======================================================================
%    u1   i1   u2   i2   u3   i3   u4   i4   u5   i5   u6   i6   % Spaltenzuordnung
a = [ 1,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0;  % Spannungsquelle
      0,   0,   1, -r2,   0,   0,   0,   0,   0,   0,   0,   0;  % Widerstand 2
      0,   0,   0,   0,   1, -r3,   0,   0,   0,   0,   0,   0;  % Widerstand 3
      0,   0,   0,   0,   0,   0,   1, -r4,   0,   0,   0,   0;  % Widerstand 4
      0,   0,   0,   0,   0,   0,   0,   0,   1, -r5,   0,   0;  % Widerstand 5
      0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   1, -r6;  % Widerstand 6
     -1,   0,   1,   0,  -1,   0,   0,   0,   0,   0,   0,   0;  % Masche 1
      0,   0,  -1,   0,   0,   0,  -1,   0,   0,   0,  -1,   0;  % Masche 2
      0,   0,   0,   0,   1,   0,   0,   0,   1,   0,   1,   0;  % Masche 3
      0,   1,   0,  -1,   0,   0,   0,   1,   0,   0,   0,   0;  % Knoten 1
      0,  -1,   0,   0,   0,  -1,   0,   0,   0,   1,   0,   0;  % Knoten 2
      0,   0,   0,   0,   0,   0,   0,  -1,   0,  -1,   0,   1 ] % Knoten 3
   
b = [ u1;                                % Spannung der Spannungsquelle
       0;
       0;
       0;
       0;
       0;
       0;
       0;
       0;
       0;
       0;
       0]
    
% Symbolische Lsung des linearen Gleichungssystems
% =================================================
x = (a^-1)*b;
pretty(simple(x))                        % Ausgabe ins Kommandofenster

% Numerische Lsung
% =================
u1 = uu1;                                % Zuweisung
r2 = rr2;                                % aktueller
r3 = rr3;                                % Werte
r4 = rr4;
r5 = rr5;
r6 = rr6;
y  = eval(x);                            % numerische Auswertung

% Ausgabe als String
% ==================
for k=1:length(y)/2
   s(k,:) = sprintf('U%d=%+5.3f V   I%d=%+4.3f A\n',k,y(2*k-1),k,y(2*k));
end