function crpuls(r,c,dt,u0)
% crpuls(r,c,dt,u0)
% Darstellung der Spannungen im C-R-Glied mit Puls als Input.
% r  :  Widerstand in Ohm
% c  :  Kapazitt in Farad
% dt :  Lnge des Impulses in Sekunden
% u0 :  Hhe des Impulses in Volt

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1   r = 33000;   end  
if nargin<2   c = 1.0e-10; end  
if nargin<3  dt = r*c;     end  
if nargin<4  u0 = 2.5;     end

% Lsung
% ======
tau = r*c;
t = (0:599)/600*3*dt;               % Zeitachse
u1 = u0*(t<dt);                     % Puls
u2 = [zeros(1,100)  (t<dt).*(u1.*exp(-t/tau))...
      + (t>=dt).*(u1 - u0*(1 - exp(-dt/tau)).*exp(-(t - dt)/tau))];
u1 = [zeros(1,100)  u1];            % Puls
u3 = u1 - u2;
t  = [(-100:-1)/600*3*dt t];

% Graphik
% =======
fh = fullscreen('PulsRC'); 
axes('Position',[0.05 0.1 0.9 0.8]);
line(t,u1,'LineWidth',2,'Color','b'); 
line(t,u2,'LineWidth',2,'Color','r'); 
line(t,u3,'LineWidth',2,'Color','g'); 
line([t(1) t(end)],[0 0],'LineWidth',2,'LineStyle',':','Color',0.7*[1 1 1])
axis([t(1) t(end) 1.1*min([0,u2]) 1.1*max(u2)])
title('Antwort einer R-C-Schaltung auf einen Impuls','FontSize',15)
xlabel('Zeit  [s]','FontSize',15)
legend('Impuls','U_R','U_C')
