function dgl_rc(r1,c2,u0,uu)
% dgl_rc(r1,c2,u0,uu)
% Serienschaltung von Spannungsquelle, Widerstand und Kondensator.
% Symbolische Lsung der Differentialgleichung und Darstellung.
% Die Spannungsquelle ist eine Sprungfunktion.
% r1 :  Widerstand in Ohm
% c2 :  Kapazitt in Farad
% u0 :  Spannung der Spannungsquelle vor  t=0 in Volt
% uu :  Spannung der Spannungsquelle nach t=0 in Volt  

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<4  uu = 0.0;     end
if nargin<3  u0 = 1.0;     end
if nargin<2  c2 = 1.0e-10; end
if nargin<1  r1 = 140;     end

% Symbolische Lsung
% ==================
syms U0 UU R1 C2
u2 = dsolve('R1*C2*Du2 + u2 = UU', 'u2(0) = U0')
pretty(u2)

% Graphik
% =======
dt = 5*r1*c2;               % Zeitbereich fr die Darstellung
t  = (0:499)/500*dt;
R1 = r1;  C2 = c2;  U0 = u0;  UU = uu;  uc = real(eval(u2));
fh(1) = fullscreen('URC');
axes('Position',[0.05 0.1 0.9 0.8]); 
plot(t,uc); 
axis([0 dt min([0  uc]) 1.1*max(uc)])
title('R-C-Schaltung','FontSize',15)
xlabel('Zeit [s]','FontSize',15)
