function dgl_urlc(r1,l2,c3,u0)
% dgl_urlc(r1,l2,c3,u0)
% Serienschaltung von Spannungsquelle, Widerstand, Spule und Kondensator.
% Symbolische Lsung der Differentialgleichung und Darstellung fr die Flle
% aktueller, aperiodisch, aperiodischer Grenzfall, gedmpft periodisch.
% Bei den letzten drei Fllen sind die Widerstnde geeignet gewhlt. 
% Die Spannungsquelle ist eine Sprungfunktion.
% r1 :  Widerstand in Ohm
% l2 :  Induktivitt in Henry
% c3 :  Kapazitt in Farad
% u0 :  Spannung der Spannungsquelle nach t=0 in Volt (vorher 0)  

% K. v. d. Heide,  e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<4  u0 = 1.0;     end
if nargin<3  c3 = 1.0e-10; end
if nargin<2  l2 = 1.0e-6;  end
if nargin<1  r1 = 140;     end

% Symbolische Lsung
% ==================
syms U0 R1 L2 C3
u3 = dsolve('L2*C3*D2u3 + R1*C3*Du3 + u3 = U0', 'u3(0) = 0', 'Du3(0) = 0')
pretty(u3)

% Graphik
% =======
w0 = 1/sqrt(l2*c3);       % Kennfrequenz
ra = 2*l2*w0;             % Widerstand im aperiodischen Grenzfall
dt = 30/w0;               % Zeitbereich fr die Darstellung
t  = (0:499)/500*dt;

R1 = r1;  L2 = l2;  C3 = c3;  U0 = u0; uc = real(eval(u3));
fh(1) = fullscreen(['R1=' num2str(R1)],'w',0,[4,1; 4 1]);
axes('Position',[0.03 0.1 0.94 0.8]); plot(t,uc); axis([0 dt min(uc) 1.1*max(uc)])
text(dt/2,0.3*U0,'aktueller Fall','FontSize',15,'HorizontalAlignment','center')
xlabel('Zeit [s]','FontSize',15)

R1 = ra; uc = real(eval(u3));
fh(2) = fullscreen(['R1=' num2str(R1)],'w',0,[4,1; 3 1]);
axes('Position',[0.03 0.1 0.94 0.8]); plot(t,uc); axis([0 dt min(uc) 1.1*max(uc)])
text(dt/2,0.3*U0,'aperiodischer Grenzfall','FontSize',15,'HorizontalAlignment','center')
xlabel('Zeit [s]','FontSize',15)

R1 = round(0.15*ra); uc = real(eval(u3));
fh(3) = fullscreen(['R1=' num2str(R1)],'w',0,[4,1; 2 1]);
axes('Position',[0.03 0.1 0.94 0.8]); plot(t,uc); axis([0 dt min(uc) 1.1*max(uc)])
text(dt/2,0.3*U0,'gedmpft periodisch','FontSize',15,'HorizontalAlignment','center')
xlabel('Zeit [s]','FontSize',15)

R1 = round(3*ra);  uc = real(eval(u3)); 
fh(4) = fullscreen(['R1=' num2str(R1)],'w',0,[4,1; 1 1]); 
axes('Position',[0.03 0.1 0.94 0.8]); plot(t,uc); axis([0 dt min(uc) 1.1*max(uc)])
text(dt/2,0.3*U0,'aperiodisch','FontSize',15,'HorizontalAlignment','center')
xlabel('Zeit [s]','FontSize',15)
