function inverterchar(u0,uths,uthl,ks,kl,g0,g1)
% inverterchar(u0,uths,uthl,ks,kl,g0,g1)
% Transfercharakteristik eines MOS-Inverters mit Lasttransistor
% Parameter (Defaults in Klammern):
% u0  :  Betriebsspannung in Volt (2.5)
% uths:  Schwellenspannung des aktiven MOS-Transistors in Volt (0.8)
% uthl:  Schwellenspannung des selbstleitenden MOS-Transistors in Volt (-1.0 < 0!)
% ks  :  Konstante des aktiven MOS-Transistors (10^-7)
% kl  :  Konstante des selbstleitenden Last-Transistors (10^-8)
% g0  :  obere Grenze der Reprsentation einer 0  (nicht angegeben)
% g1  :  untere Grenze der Reprsentation einer 1 (u0 - g0)

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1    u0 = 2.5;   end
if nargin<2  uths = 0.8;   end
if nargin<3  uthl = -1.0;  end
if nargin<4    ks = 10^-7; end
if nargin<5    kl = 10^-8; end
n = 500;                                 % Anzahl der Abszissenpunkte in den drei Bereichen

% Berechnung der Kurven
% =====================
ux1 = uths + (0:2*n)/2/n*u0;             % Abszisse
uy1 = real(u0 + uthl + sqrt(uthl^2-ks/kl*(ux1-uths).^2)); % Ausgangsspannung
ixg = min(find(uy1<=u0+uthl));           % Index der Abschnrgrenze des Lasttransistors
uy1 = uy1(1:ixg);                        % Beschrnkung auf Abschnrbereich
ux1 = ux1(1:ixg);                        % Beschrnkung auf Abschnrbereich
ux2 = ux1(end) + (0:n)/n*(u0-ux1(end));  % Abszisse im Widerstandsbereich des Schalttransistors
uy2 = real(ux2 - uths - sqrt((ux2-uths).^2-kl/ks*uthl^2)); % Ausgangsspannung im Widerstandsbereich

% Graphik
% =======
fh = fullscreen('MOS-Inverter');
if nargin>5
   if nargin<7  g1 = u0 - g0; end
   patch([0 g0 g0 0],[0 0 g1 g1],[1 0.7 0.7],'EdgeColor','none')
   patch([g1 u0 u0 g1],[g0 g0 u0 u0],[1 0.7 0.7],'EdgeColor','none')
   patch([g0 g0 g1 g1],[0 u0 u0 0],[0.7 1 0.7],'EdgeColor','none')
end
line([0 uths],[u0 u0],'Color','g','LineWidth',2)
line(ux1,uy1,'Color','r','LineWidth',2)
line([ux1(end) ux2(1)],[uy1(end) uy2(1)],'Color','b','LineWidth',2)
line(ux2,uy2,'Color','m','LineWidth',2)
axis([0 u0 0 1.1*u0]);  axis square
xlabel('Eingangsspannung in V','FontSize',15)
ylabel('Ausgangsspannung in V','FontSize',15)
title('Transfercharakteristik eines N-MOS-Inverters','FontSize',15)
legend('Sperrbereich','Widerstandsbereich des Lasttransistors','Abschnrbereich','Widerstandsbereich des Schalttransistors')
