function r = lsgt2_3_2(ron,roff,uth,u0,d)
% r = lsgt2_3_2(ron,roff,uth,u0,d)
% Lsung zur Aufgabe T2/3.2
% Ein MOS-Transistor wird modelliert durch zwei Widerstnde 
% ron (x=1) und roff (x=0), zwischen denen umgeschaltet wird 
% durch die Steuergrsse  x = UGS>uth.  Dieses Transistormodell 
% zusammen mit einem Lastwiderstand r ergibt einen Inverter.
% Der Lastwiderstand soll so gewhlt werden, dass die Ausgangsspannung 
% des Inverters im ON- und im OFF-Zustand des Transistors gleichen 
% Abstand von uth hat (aber mit unterschiedlichem Vorzeichen).
% ron  :  ON-Widerstand des Transistors     (10 kOhm)
% roff :  OFF-Widerstand des Transistors    (200 kOhm)
% uth  :  Schwellenspannung des Transistors (1.2 V)
% u0   :  Betriebsspannung des Inverters    (3 V)
% d    :  Abstand der Intervalle fr 0 / 1  (0.8 V)
%
% Lsungsweg:
% Die Ausgangsspannung des Inverters ist entweder
% uon = u0*ron/(r+ron) oder uoff = u0*roff/(r+roff)
% Aus der Forderung  uth-uon=uoff-uth folgt
% ron/(r+ron) + roff/(r+roff) = 2*uth/u0
% Diese nichtlineare Gleichung ist zu lsen.

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaultwerte (in der Aufgabe angegebene Werte)
% ==============================================
if nargin<1   ron = 10^4;   end
if nargin<2  roff = 2*10^5; end
if nargin<3   uth = 1.2;    end
if nargin<4    u0 = 3;      end
if nargin<5     d = 0.8;    end

% Symbolische Lsung
% ==================
syms rron rroff rr uu0 uuth
fkt = solve('rron/(rr+rron) + rroff/(rr+rroff) = 2*uuth/uu0','rr');

% Numerische Auswertung
% =====================
rron  = ron;
rroff = roff;
uuth  = uth;
uu0   = u0;
for k=1:length(fkt)  r(k) = eval(fkt(k,:)); end
r     = r(find(r>=0 & isreal(r)));
uoff  = u0*roff/(r+roff);
uon   = u0*ron/(r+ron);

% Graphik
% =======
u1 = uth - d/2;
u2 = uth + d/2;
figure
axis([0 u0 0 u0]); axis square
patch([0 u1 u1 0],[0 0 u2 u2],[1 0.7 0.7],'EdgeColor','none')
patch([u2 u0 u0 u2],[u1 u1 u0 u0],[1 0.7 0.7],'EdgeColor','none')
patch([u1 u2 u2 u1],[0 0 u0 u0],[0.7 1 0.7],'EdgeColor','none')
line([0 u0],uth*[1 1],'LineWidth',2,'Color','r')
line([0 uth],uoff*[1 1],'LineWidth',2)
line([uth u0],uon*[1 1],'LineWidth',2)
line([uth uth],[uoff uon],'LineWidth',2)
xlabel('Inputspannung [V]','FontSize',12)
ylabel('Outputspannung [V]','FontSize',12)
title('Transfercharakteristik des Invertermodells','FontSize',15)
