%
%
%2.3  Zeitabhngige lineare Netze %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-4,'Color',MSVTITLCOLOR>
%
%
%
% Lineare Netze sind zeitabhngig, wenn sie Komponenten enthalten, deren 
% Strom-Spannungs-Verhalten sich nur mithilfe von Integralen ber die Zeit 
% oder durch Ableitungen nach der Zeit beschreiben lsst.  Es gibt zwei 
% Basiselemente dieser Art:  Kondensator und Spule.
%
% Beim Kondensator ist die Ladung  {\fontname{Courier}Q}  proportional zur Spannung.  Die 
% Proportionalittskonstante heisst Kapazitt und wird meist mit  {\fontname{Courier}C}  bezeichnet:
%
% {\fontname{Courier}Q = C*U}
%
% Die Einheit der Kapazitt ist  {\fontname{Courier}As/V = F} (Farad nach Faraday).  Die Kapazitt 
% ist eine Bauteilkonstante.  Sie entspricht nicht der Kapazitt einer Milchkanne 
% sondern eher deren Querschnitt.  Je hher man auffllt (entsprechend der Spannung) 
% desto mehr ist drin.
%
% Der Strom  {\fontname{Courier}I}  ergibt sich als Ableitung der Ladung nach der Zeit.  Damit ergibt 
% sich die Verhaltensbeschreibung des Kondensators zu
%
% {\fontname{Courier}I = C dU/dt}   oder   {\fontname{Courier}dU/dt - (1/C) I = 0}
%
% Ist  {\fontname{Courier}U(t)}  bekannt, so folgt daraus direkt durch Ableitung  {\fontname{Courier}I(t)} .  Sei z.B. ein 
% Kondensator von  {\fontname{Courier}C = 1\muF}  am  {\fontname{Courier}230V-}Netz  angeschlossen.  Dann ist  
%
% {\fontname{Courier}U = 325*sin(2*\pi*50*t) V}  
%
% {\fontname{Courier}I = 10^{-6}*325*2*\pi*50*cos(2*\pi*50*t) A  =  0.1021*cos(2*\pi*50*t) A} .
%
c  = 1.0e-6;                        % Kapazitt in Farad
t  = (0:499)/500*0.04;              % Zeitbereich von zwei Schwingungen der Netzfrequenz
u  = 325*sin(2*pi*50*t);            % Netzspannung
i  = c*325*2*pi*50*cos(2*pi*50*t);  % Strom durch den Kondensator
fh = fullscreen('C');
line(t([1 end]),[0 0],'Color',0.7*[1 1 1],'LineStyle',':','LineWidth',2)
line(t,u,'Color','b','LineWidth',2);  axis([t(1) t(end) 1.1*max(u)*[-1 1]])
line(t,u.*i,'Color','g','LineWidth',2);
xlabel('Zeit  [ s ]','FontSize',14)
ylabel('Spannung  [ V ]','FontSize',14)
title('Kondensator am Versorgungsnetz','FontSize',15)
ua = gca;
set(ua,'XColor','k','YColor','b')
ia = axes('Position',get(ua,'Position'),'YAxisLocation','right','Color','none','YColor','r');
line(t,i,'Color','r','LineWidth',2);  axis([t(1) t(end) 1.1*max(i)*[-1 1]])
ylabel('Strom  [ A ]','FontSize',14)
%
% Die Leistung  {\fontname{Courier}P(t)=U(t)*I(t)}  ist im Bild grn eingezeichnet.  Man erkennt, dass die 
% mittlere Leistung verschwindet.
%
% 
% Die Verhaltensbeschreibung einer Spule ist 
%
% {\fontname{Courier}U = L dI/dt}
%
% {\fontname{Courier}L}  ist eine Bauteilkonstante.  Sie heisst Induktivitt und hat die Einheit  {\fontname{Courier}Vs/A = H (Henry)} .
% 
%
% Die Analyse von zeitabhngigen Netzen ist aufwndiger als die von zeitunabhngigen, 
% weil sich anstelle eines einfachen linearen Gleichungssystems ein System von gewhnlichen 
% linearen Differentialgleichungen mit konstanten Koeffizienten ergibt.  Differentialgleichungen 
% sind spezielle Funktionalgleichungen, d.h. Gleichungen deren Lsungen Funktionen anstelle 
% von Zahlenwerten sind.  Im vorliegenden Fall ergeben sich Zeitfunktionen.
%
%% Hier als Beispiel U-R-C auf OH-Folie
%
% Die manuelle formale Lsung ist bei grossen Netzen mhselig und fehleranfllig. 
% Eine Alternative ist die Rechner-gesttzte Lsung mit symbolischer Mathematik. 
% Eine numerische Integration ist auch mglich, hat aber den Nachteil, dass die 
% Berechnung fr jeden Einzelfall durchgefhrt werden muss.
%
%
% Die symbolische Lsung des obigen Beispiels wird durchgefhrt durch die folgende 
% Funktion:
%
edit('dgl_rc')
%
% Der Aufruf mit den Defaultwerten ergibt:
%
dgl_rc
%
% Die Lsung der linearen Differentialgleichung erster Ordnung ist immer eine e-Funktion, 
% wenn die Quellen konstant sind.  Wir nehmen im folgenden Fall als Spannungsquelle 
% einen Impuls.  Strom und Spannung setzen sich dann stckweise aus e-Funktionen 
% zusammen:
%
help crpuls
%
crpuls(1000,1.0e-9,1.0e-6,5)
%
crpuls(1000,1.0e-9,1.0e-5,5)
% 
crpuls(1000,1.0e-9,1.0e-4,5)
%
% Auch fr Spannungsquellen mit anderem Zeitverlauf bekommt man meistens eine Lsung. 
% Bei der Funktion  {\fontname{Courier}urc}  kann man die Zeitfunktion als Ausdruck eingeben:
% 
help urc
%
% Wir tun dies zunchst fr eine Sinus-Schwingung:
%
urc('2*sin(2*pi*20000*t)',1000,10^-8,[0  0.0001])
%
% Als zweites Beispiel nehmen wir einen aus zwei Sprungfunktionen synthetisierten Impuls 
% und erhalten natrlich das selbe Ergebnis wie oben fr den Impuls:
%
urc('5*Heaviside(t)-5*Heaviside(t-0.00005)',1000,10^-8,[0  0.0001])
%
%
% Netze mit Kondensatoren und Spulen ergeben immer lineare Differentialgleichungen 
% zweiter Ordnung, deren allgemeine Lsung die Summe zweier komplexer e-Funktionen 
% ist.  Daraus lassen sich drei Flle ableiten:
%
% (a)  der aperiodische Fall
%
% (b)  der (gedmpft) periodische Fall
%
% (c)  der aperiodische Grenzfall
%
% Zur Demonstration whlen wir die Serienschaltung von  Spannungsquelle, Widerstand,
% Kondensator und Spule.  Das Gleichungssystem mit Verhaltensbeschreibungen, Maschen-
% und Knotenregeln ergibt nach Umformung schliesslich die Differentialgleichung
%
% {\fontname{Courier}L2*C3*d^2u3/dt^2 + R1*C3*du3/dt + u3 = U0}
% 
% mit den Anfangsbedingungen
%
% {\fontname{Courier}u3(0) = 0}   und   {\fontname{Courier}du3/dt(0) = 0}
%
% Diese sind Kern der Funktion  {\fontname{Courier}dgl\_rlc} :
%
edit('dgl_rlc')
%
% Der Aufruf mit den Defaultwerten ergibt:
%
dgl_rlc
%
%
% Kapazitten und Induktivitten treten unvermeidlich bei jeder elektrischen Schaltung auf. 
% Digitale Signale haben deshalb immer eine endliche Steilheit der Flanken und hufig 
% berschwinger.
%