%
%
%9.2.1 Fouriertransformation %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE,'Color',MSVTITLCOLOR>
%
%
%
%  Die Fouriertransformation transformiert ein reellwertiges oder komplexwertiges 
%  Signal vom Zeitbereich in den Frequenzbereich.  Die Zeitvariable sei  {\fontname{Courier}t} , die 
%  Frequenzvariable ist entweder die Frequenz  {\fontname{Courier}f}  mit der Einheit 
%  Hertz [Hz] = 1 Schwingung / Sekunde                      %<'FontName',MSVFORMFONT>
%
%  oder die sog. Kreisfrequenz (die eigentlich die Winkelgeschwindigkeit ist)
%  \omega = 2\pi\cdotf .                                    %<'FontName',MSVFORMFONT>
%
%  Der Frequenzbereich heisst auch Spektralbereich.
%
%  Gegeben sei das Signal  \fontname{Courier}s(t) .
%
%  Dann heisst
%         \infty                                            %<'FontName',MSVFORMFONT>
%  S(\omega) = _{\fontsize{24}\int} s(t) e^{-i\omegat} dt   %<'FontName',MSVFORMFONT>
%        -\infty                                            %<'FontName',MSVFORMFONT>
%  Fouriertransformierte von  {\fontname{Courier}s}  (sofern sie existiert).
%
%  {\fontname{Courier}S}  ist eine zu  {\fontname{Courier}s}  quivalente Darstellung des Signals. 
%  Man beachte, dass die Fouriertransformierte fr reale Signale zur Zeit  \tau  nur 
%  berechnet werden kann, wenn   {\fontname{Courier}s(t)}  fr alle  {\fontname{Courier}t > \tau}  bekannt ist, also z.B. periodisch 
%  ist oder  {\fontname{Courier}s(t) = 0}  fr  {\fontname{Courier}t > \tau} .  Der Absolutbetrag der Fouriertransformierten 
%  wird als Spektrum bezeichnet.
%
%  Die MATLAB-Funktion zur symbolischen Ermittlung der Fouriertransformierten ist 
%  {\fontname{Courier}fourier} :
%
help fourier
%
%  Wegen
%
%  e^{-ix} = cos(x) - i\cdotsin(x)                          %<'FontName',MSVFORMFONT> 
%
%  ist der Realteil der Fouriertransformierten einer reellen Funktion eine gerade Funktion 
%  in  \omega  und der Imaginrteil eine ungerade Funktion. Wegen dieser Symmetrie zeigen wir 
%  hufig nur  {\fontname{Courier}S(\omega)}  fr  {\fontname{Courier}\omega > 0}.
%
%  Ist berdies die Funktion  {\fontname{Courier}s(t)}  schon eine gerade Funktion, so verschwindet der 
%  Imaginrteil der Fouriertransformierten.  Umgekehrt ist die Fouriertransformierte 
%  einer ungeraden Funktion rein imaginr.
%
%  {\fontname{Courier}fourier}  wird in folgenden Beispielen in der Funktion  {\fontname{Courier}fourierplot}  benutzt.
%
%%  fourierplot  zeichnet links die Funktion im Zeitbereich und rechts im 
%%  Frequenzbereich.  Beide Bilder lassen sich mit der Maus drehen. 
%%  (Prfen Sie z.B. die Symmetrien auf der linken Seite!)
%
%
%  \bfBeispiele
%
%  Ungerade Funktion    {\fontname{Courier}e^{-t^2}sin(t)}
%
syms t w; A=fourierplot('exp(-t^2)*sin(t)',t,w,[-5,5],[-10,10])
%
%  gerade Funktion      {\fontname{Courier}e^{-t^2}cos(t)}
%
syms t w; B=fourierplot('exp(-t^2)*cos(t)',t,w,[-5,5],[-10,10])
%
%  keine Symmetrie      {\fontname{Courier}e^{-t^2}\cdot(sin(t)+2\cdotcos(2t))}
%
syms t w; C=fourierplot('exp(-t^2)*(sin(t)+2*cos(2*t))',t,w,[-5,5],[-10,10])
%
%%  Drehen Sie die Fouriertransformierte in 2D-Sicht, um die Symmetrie zu erkennen:  
%%  Realteil ber  {\fontname{Courier}\omega}   bzw.  Imaginrteil ber {\fontname{Courier}\omega}.
%%  Lassen Sie die letzten beiden Bilder stehen, um die nachfolgende Rcktransformation 
%%  berprfen zu knnen.
%
%  Nun wird die eben ermittelte Fouriertransformierte  {\fontname{Courier}C}  mit der inversen 
%  Fouriertransformation in den Zeitbereich zurcktransformiert:
%
c = ifourierplot(C,w,t,[-10,10],[-5,5]) % Rcktransformation
%
%  Der symbolische Funktionsausdruck ist quivalent und der Funktionsverlauf identisch.
%
%%  Eine berprfung ist mglich durch wechselseitiges Anklicken der beiden Bilder 
%%  "Funktion".
%
%  Bei der Fouriertransformation einer Sinusschwingung  {\fontname{Courier}cos(2\pif_0t)}  divergiert 
%  das Integral an den Stellen  {\fontname{Courier}\omega = 2\pi f_0}  und  {\fontname{Courier}\omega = -2\pi f_0} . 
%  berall sonst verschwindet es. Die Transformierte ist die Summe zweier Dirac'scher 
%  Deltafunktionen:
%
syms t,w; f0=3.0; ft=fourierplot(cos(2*pi*f0*t),t,w); 
expand(ft)
%
%
%%  Aufgabe 9.2.1: Bestimmen Sie wie oben die Fouriertransformierte von 
%            sin(2\pif_0t)  %<'FontName',MSVFORMFONT>
%%  mit  
%            f_0 = 3.0.     %<'FontName',MSVFORMFONT>
%%
%%  Interpretieren Sie das Ergebnis, insbesondere die Symmetrien.
%
%%  Aufgabe 9.2.2: Der Ausdruck der Fouriertransformierten (siehe im Kommandofenster) 
%%  hat zwei Terme. Berechnen Sie die Zeitfunktion fr jeden der beiden Terme getrennt 
%%  durch inverse Fouriertransformation. Wenn es hierbei zu einer nicht nachvollziehbaren 
%%  Fehlermeldung kommt, setzen Sie den Ausdruck der Fouriertransformierten in 
%%  Stringquotes '...'  (Das Problem, alle Funktionen einschliesslich der Distributionen 
%%  gleichzeitig symbolisch und numerisch zu behandeln, ist noch nicht zufriedenstellend gelst).  
%%
%%  Aus welchen Komponenten setzt sich also jede reelle Sinus- bzw. Kosinus-Schwingung 
%%  zusammen? Worin besteht der Unterschied der beiden Komponenten im Zeitbereich? 
%%  Betrachten Sie jeweils den Realteil ber t und den Imaginrteil ber t.
%
help ifourierplot
%
