%
%
%9.2.4  Diskrete Fouriertransformation %<'FontWeight',MSVTITLWEIGHT,'FontSize',MSVTITLSIZE-6,'Color',MSVTITLCOLOR>
%
%
%
%  Die Fouriertransformierte einer im Zeitbereich diskreten und zugleich periodischen 
%  Funktion ist auch im Frequenzbereich periodisch und diskret.  Zwar sind Signale im 
%  Zeitbereich meistens nicht periodisch, dennoch hat die diskrete Fouriertransformation 
%  eine zentrale Bedeutung in der digitalen Signalverarbeitung, nmlich weil die auf 
%  dem Rechner notwendige Diskretisierung im Zeit- wie auch im Frequenzbereich nur 
%  diese Art der numerischen Fouriertransformation zulsst.   
%
%  Mit der Abtastfrequenz  {\fontname{Courier}f_s = 1/\deltat} ,  wo  {\fontname{Courier}\deltat}  der zeitliche Abstand der 
%  Abtastungen ist, ergibt sich die Periode im Frequenzbereich zu  {\fontname{Courier}f_s} .
%
%  Ist das Zeitsignal periodisch mit der Periode  {\fontname{Courier}T} , so ist die Fouriertransformierte 
%  frequenzdiskret mit Frequenzschritten  {\fontname{Courier}\deltaf = 1/T} .
%
%  Die Periode des Zeitbereiches enthalte  {\fontname{Courier}N = T/\deltat}  Abtastungen.  Genauso viele 
%  Frequenzschritte enthlt dann die Periode im Frequenzbereich:  {\fontname{Courier}f_s/\deltaf = T/\deltat = N} .
%
%  Beispiel:  
%  {\fontname{Courier}          f_s = 8 kHz   }also{\fontname{Courier}   \deltat = 1/f_s = 0.125 ms}
%  {\fontname{Courier}          \Deltaf = 10 Hz   }also{\fontname{Courier}   T = 1/\Deltaf = 0.1 s}
%
%  Die diskrete Fouriertransformation ergibt sich entsprechend den beiden vorangegangenen 
%  Abschnitten 9.2.2 und 9.2.3 .  Dabei treten in der Periode des Frequenzbereiches  {\fontname{Courier}N}  
%  quidistante Frequenzen  {\fontname{Courier}f_k = k\deltaf = kf_s/N}  auf, und im Zeitbereich bilden die 
%  {\fontname{Courier}N}  Signalabtastungen  {\fontname{Courier}x_n}  an den Zeitpunkten  {\fontname{Courier}n\deltat = n/f_s}  
%  ebenfalls eine Periode.
%
%  Die Fouriertransformierte des zeitdiskreten periodischen Signals  {\fontname{Courier}x_n}  ist dann:
%      N-1                                                %<'FontName',MSVFORMFONT>
%  X_k = _{\fontsize{26}\Sigma} x_n e^{-i2\pikn/N}        %<'FontName',MSVFORMFONT>
%      n=0                                                %<'FontName',MSVFORMFONT>
%
%  Entsprechend erhlt man die inverse diskrete Fouriertransformierte:
%            N-1                                          %<'FontName',MSVFORMFONT>
%  x_n = (1/N) _{\fontsize{26}\Sigma} X_k e^{i2\pikn/N}   %<'FontName',MSVFORMFONT>
%            k=0                                          %<'FontName',MSVFORMFONT>
%
%  Demonstration mit der Funktion  {\fontname{Courier}plotzeitfreq} :
%  f = 2 Hz;  fs = 30 Hz;  Zeitperiode = 2 s              %<'FontName',MSVFORMFONT>
%
%  ==>  Periode im Frequenzbereich = f_s = 30 Hz;         %<'FontName',MSVFORMFONT>
%       Abstand der Punkte im Frequenzbereich = 1/Zeitperiode = 0.5 Hz %<'FontName',MSVFORMFONT>
%
plotzeitfreq('sin(2*pi*2.0*t)',30,2);
%
%  In diesem Fall passen die Perioden im Zeitbereich so zusammen, dass ein 
%  kontinuierlicher Sinus entsteht mit entsprechendem Dirac-Puls als Spektrum. 
%  Man beachte, dass  {\fontname{Courier}20 dB}  einer Dekade entsprechen.  
%  {\fontname{Courier}-300 dB}  sind also  {\fontname{Courier}10^{-15}} .  Das ist numerisches Rauschen.
%
%  Wenn die Perioden im Zeitbereich nicht stetig differenzierbar zusammenpassen, 
%  gibt es ein anderes Spektrum, da eine abgeschnittene Sinusperiode bei der 
%  Fourierreihe nicht durch eine Sinuskomponente allein dargestellt werden kann:
%
plotzeitfreq('sin(2*pi*2.25*t)',30,2);
%
plotzeitfreq('sin(2*pi*2.125*t)',30,2);
%
%  Bei Signalen, die aus vielen Komponenten zusammengesetzt sind, betrifft dies 
%  jede Komponente individuell.  Eine kann also als Dirac-Puls im Spektrum erscheinen, 
%  eine andere verbreitert.  Man beachte, dass im folgenden Beispiel die Perioden sogar
%  stetig aneinanderpassen:
%
plotzeitfreq('sin(2*pi*6*t)+sin(2*pi*2.25*t)',30,2);
%
%  Besonders kritisch ist dies, wenn Komponenten im Spektrum gesucht werden. 
%  Im folgenden Beispiel ist eine um den Faktor  {\fontname{Courier}0.001}  schwchere 
%  Komponente auf  {\fontname{Courier}4.0 Hz} gut auszumachen neben der von  {\fontname{Courier}3.0 Hz} , weil sich 
%  beide Komponenten in der gewhlten Periode von  {\fontname{Courier}2.0 s}  genau fortsetzen. 
%
plotzeitfreq('sin(2*pi*3*t)+0.001*sin(2*pi*4*t)',30,2);
%
%  Wird jedoch die Frequenz der grsseren Komponente sehr geringfgig auf  {\fontname{Courier}3.01 Hz} 
%  gendert, so ist von der anderen nichts mehr zu erkennen:
%  
plotzeitfreq('sin(2*pi*3.01*t)+0.001*sin(2*pi*4*t)',30,2);
%
%  Eine nderung der Zeitperiode kann dasselbe bewirken:
%
plotzeitfreq('sin(2*pi*3.0*t)+0.001*sin(2*pi*4*t)',30,2.01);
%
%  Die Abtastrate hat dagegen keinen Einfluss auf die Auflsung im Frequenzbereich:
%
plotzeitfreq('sin(2*pi*3.0*t)+0.001*sin(2*pi*4.0*t)',39.713,2);
%
plotzeitfreq('sin(2*pi*3.0*t)+0.001*sin(2*pi*4.0*t)',59.713,2);
%
%  Der demonstrierte Effekt der unterschiedlichen Auflsung innerhalb der 
%  Fouriertransformierten ist begrndet durch die Diskretisierung im Zeit- 
%  und Frequenzbereich.  Er wird in der Praxis durch punktweise Multiplikation 
%  des Signals mit einer sog. Fensterfunktion abgemildert.
%
%  Die Auflsung im Frequenzbereich ist zum einen begrenzt durch den eben 
%  beschriebenen Effekt der Verschmierung von Komponenten und zum anderen 
%  gegeben durch den  {\fontname{Courier}Frequenzschritt = 1/Zeitperiode} .  Man kann 
%  diese Auflsung also durch Vergrsserung der Zeitperiode erhhen.  Dies 
%  gelingt auch dann, wenn ein schon in  {\fontname{Courier}N}  Punkten abgetastetes Signal vorliegt. 
%  In diesem Fall kann man dem Signal einfach Nullen als weitere Abtastwerte 
%  hinzufgen.  Das vergrssert die Anzahl der Sttzstellen des Spektrums. 
%  Es ist aber auch zu sehen, dass die Trennung von Komponenten kaum
%  besser wird:
%
plotzeitfreq('sin(2*pi*3.1*t)+0.5*sin(2*pi*4.0*t)',10,2);
%
plotzeitfreq('(t<2).*(sin(2*pi*3.1*t)+0.5*sin(2*pi*4.0*t))',10,4);
%
plotzeitfreq('(t<2).*(sin(2*pi*3.1*t)+0.5*sin(2*pi*4.0*t))',10,10);
%
%  Optisch kann sich das Bild auch deutlich verschlechtern, wenn nmlich das
%  Anfgen von Nullen das nahtlose Aneinanderpassen der Perioden zerstrt:
%
plotzeitfreq('(t<2).*(sin(2*pi*3.0*t)+0.5*sin(2*pi*4.0*t))',20,2);
%
plotzeitfreq('(t<2).*(sin(2*pi*3.0*t)+0.5*sin(2*pi*4.0*t))',20,2.1);
%
plotzeitfreq('(t<2).*(sin(2*pi*3.0*t)+0.5*sin(2*pi*4.0*t))',20,4);
%
%  Fr die diskrete Fouriertransformation gibt es effiziente Algorithmen, die als 
%  Fast Fourier Transform (FFT) bezeichnet werden.  Weil sie linear und endlich ist, 
%  kann sie auch als Matrix-Vektor-Multiplikation realisiert werden mit konstanter Matrix.
%
