function transferchar(u0,uth,r,k)
% transferchar(u0,uth,r,k)
% Transfercharakteristik eines MOS-Verstrkers mit Lastwiderstand
% u0  :  Betriebsspannung in Volt
% uth :  Schwellenspannung in Volt
% r   :  Lastwiderstand in Ohm
% k   :  Konstante des MOS-Transistors

% Autor: Klaus von der Heide, e-mail:  v.d.heide@on-line.de

% Defaults
% ========
if nargin<1   u0 = 5;     end
if nargin<2  uth = 1.0;   end
if nargin<3    r = 10^5;  end
if nargin<4    k = 10^-4; end
n = 500;                                % Anzahl der Abszissenpunkte in den drei Bereichen

% Berechnung der Kurven
% =====================
ux1 = uth + (0:2*n)/2/n*u0;             % Abszisse
uy1 = u0-r*0.5*k*(ux1-uth).^2;          % Ausgangsspannung
ixg = min(find(uy1<ux1-uth)) - 1;       % Index der Abschnrgrenze
uy1 = uy1(1:ixg);                       % Beschrnkung auf Abschnrbereich
ux1 = ux1(1:ixg);                       % Beschrnkung auf Abschnrbereich
ux2 = ux1(end) + (0:n)/n*(u0-ux1(end)); % Abszisse im Widerstandsbereich
uu  = ux2 - uth + 1/r/k;                % Hilfsspannung
uy2 = uu-sqrt(uu.^2-2*u0/r/k);          % Ausgangsspannung im Widerstandsbereich

% Graphik
% =======
fh = fullscreen('MOS-AMP');
line([0 uth],[u0 u0],'Color','b','LineWidth',2)
line(ux1,uy1,'Color','r','LineWidth',2)
line(ux2,uy2,'Color','g','LineWidth',2)
axis([0 u0 0 1.1*u0]);  axis square
xlabel('Eingangsspannung in V','FontSize',15)
ylabel('Ausgangsspannung in V','FontSize',15)
title('Transfercharakteristik eines MOS-Verstrkers mit Lastwiderstand','FontSize',15)
legend('Sperrbereich','Abschnrbereich','Widerstandsbereich')