function s = urc(u1,r2,c3,tt)
% s = urc(u1,r2,c3,tt)
% Serienschaltung von Spannungsquelle, Widerstand 
% und Kondensator
% u1  :  String mit der Funktion U(t) fr die Spannungsquelle
% r2  :  Widerstand in Ohm
% c3  :  Kapazitt in Farad
% tt  :  Vektor mit den beiden Zeitgrenzen fr die Graphik
% Beispiel:  urc('2*sin(2*pi*100000*t)',1000,10^-8,[0  0.00003])

syms t u3 c r; 

% Defaultwerte
% ============
if nargin<4 tt = [0  0.00005]; end 
if nargin<3 c3 = 10^-9; end
if nargin<2 r2 =  1000; end
if nargin<1 u1 = '5*Heaviside(t)'; end

% Symbolische Lsung der Differentialgleichung
% ============================================
u3 = dsolve(['Du3=(' u1 '-u3)/c/r'],'u3(0)=0');
pretty(simple(u3))

% Numerische Lsung
% =================
r = r2;                                    % aktuelle
c = c3;                                    % Werte
n = 500;                                   % Anzahl der Punkte der Graphik
ttt = tt(1) + (0:n)/n*(tt(2)-tt(1));       % Zeitbereich
for k=1:n+1 
   t = ttt(k); 
   uc(k) = eval(u3);                       % numerische Auswertung
   uu(k) = eval(u1);
   ur(k) = uu(k) - uc(k);
end; 

% Graphik
% =======
fh = fullscreen('U-R-C'); 
line(ttt,uu,'Color','b','LineWidth',2)
line(ttt,uc,'Color','r','LineWidth',2)
line(ttt,ur,'Color','g','LineWidth',2)
line([ttt(1),ttt(end)],[0 0],'Color',0.7*[1 1 1],'LineStyle',':')
mn = min([uu uc ur]);
mx = max([uu uc ur]);
axis([tt(1)  tt(2)  mn-0.1*(mx-mn)  mx+0.1*(mx-mn)])
xlabel('Zeit [s]','FontSize',13)
ylabel('u3 [ V ]','FontSize',13)
legend('U_1','U_C','U_R')
